@@ -1,9 +1,8 @@
-from django.db import models
-
-from sympycharfield.fields import SympyCharField
+from django.db                    import models
+from sympycharfield.models        import SympyCharField
 
 class SympyCharFieldTest(models.Model):
     formula = SympyCharField(max_length=255, blank=True, null=True)
     
     def __str__(self):
-        return str(self.formula)
\ No newline at end of file
+        return str(self.formula)
